#
# spec file for package libpinyin
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 9
Name:           libpinyin
Version:        1.5.92
Release:        2.11
Summary:        Intelligent Pinyin IME
License:        GPL-2.0+
Group:          System/I18n/Chinese
Url:            https://github.com/libpinyin/libpinyin
Source:         %{name}-%{version}.tar.gz
Source1:        http://netix.dl.sourceforge.net/project/libpinyin/models/model12.text.tar.gz
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE marguerite@opensuse.org - avoid download at buildtime
Patch0:         libpinyin-avoid_download_at_buildtime.patch
# PATCH-FIX-UPSTRAEM hillwood@opensuse.org - fix mapper for double pinyin
Patch1:         libpinyin-fix_double_pinyin.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1140
BuildRequires:  libdb-4_8-devel
%else
BuildRequires:  libdb-4_5-devel
%endif

%description
Libpinyin is a staging joint effort of many Chinese Pinyin IME development teams.
It aims to be an Intelligent (and Universal) Sentence-based Pinyin IME Backend
supports many Language Models and Frontends.

%package -n %{name}%{soname}
Summary:        Intelligent Pinyin IME
Group:          System/Libraries
Requires:       %{name}-data

%description -n %{name}%{soname}
Libpinyin is a staging joint effort of many Chinese Pinyin IME development teams.
It aims to be an Intelligent (and Universal) Sentence-based Pinyin IME Backend
supports many Language Models and Frontends.

This package provides runtime library for libpinyin.

%package data
Summary:        Data files for libpinyin
Group:          System/I18n/Chinese

%description data
Libpinyin is a staging joint effort of many Chinese Pinyin IME development teams.
It aims to be an Intelligent (and Universal) Sentence-based Pinyin IME Backend
supports many Language Models and Frontends.

This package provides language model table data for libpinyin.

%package devel
Summary:        Intelligent Pinyin IME
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}
Requires:       %{name}-tools = %{version}

%description devel
Libpinyin is a staging joint effort of many Chinese Pinyin IME development teams.
It aims to be an Intelligent (and Universal) Sentence-based Pinyin IME Backend
supports many Language Models and Frontends.

%package tools
Summary:        Tools for libpinyin
Group:          System/I18n/Chinese

%description tools
Libpinyin is a staging joint effort of many Chinese Pinyin IME development teams.
It aims to be an Intelligent (and Universal) Sentence-based Pinyin IME Backend
supports many Language Models and Frontends.

This package provides the tools used to make data files.

%prep
%setup -q
cp -r %{SOURCE1} data/
%patch0 -p1
%patch1 -p1
NOCONFIGURE=1 ./autogen.sh

%build
%configure --disable-static
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}

%post -n %{name}%{soname} -p /sbin/ldconfig

%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%defattr(-,root,root)
%doc ChangeLog AUTHORS COPYING README
%{_libdir}/%{name}.so.*
%{_mandir}/man1/libpinyin.1.gz

%files data
%defattr(-,root,root)
%{_libdir}/%{name}

%files tools
%defattr(-,root,root)
%{_bindir}/gen_binary_files
%{_bindir}/gen_unigram
%{_bindir}/import_interpolation

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}-*/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Wed Aug 10 2016 hillwood@opensuse.org
- Update to 1.5.92
  * use model12.text.tar.gz
  * fixes pinyin_get_character_offset function
  * fixes _get_char_offset_recur function
  * fixes _pre_compute_tokens function
  * fixes fill_matrix function
  * fixes pinyin_get_right_pinyin_offset function
  * fixes fill_matrix function
  * clean up FullPinyinParser2
- Update libpinyin-avoid_download_at_buildtime.patch
- Update baselibs.conf
- Add libpinyin-fix_double_pinyin.patch
  * fix mapper for double pinyin
* Thu Dec 24 2015 i@marguerite.su
- Update to version 1.3.0+git20151204.7b790c9:
  * support force tone in pinyin parsers
  * support fallback tables in double pinyin
  * many bugfixes and refactors
- drop patch: libpinyin-1.2.0-avoid_download_at_buildtime.patch
- add patch: libpinyin-avoid_download_at_buildtime.patch
* Tue Aug 25 2015 i@marguerite.su
- Update to version 1.2.0+git20150731.958c597:
  * fixes Kyoto Cabinet bug
  * Resolve NULL used in arithmetic
  * Resolve ambiguos usage of log(3)
  * bump version 1.2.0
- add patch: libpinyin-1.2.0-avoid_download_at_buildtime.patch
- remove patch: libpinyin-1.0.99.20150212-avoid_download_at_buildtime.patch
* Wed Apr  8 2015 hillwood@linuxfans.org
- Update to 1.1.0
  * support to export user phrases.
* Sun Feb 15 2015 hillwood@linuxfans.org
- Update to 1.0.99.20150212
  * fixes pinyin_get_pinyin_key_rest_offset method
  * fixes pinyin_iterator_get_next_phrase method
- Update patch file:
  remove old: libpinyin-1.0.0-avoid_download_at_buildtime.patch
  add new: libpinyin-1.0.99.20150212-avoid_download_at_buildtime.patch
* Sat Jul 26 2014 i@marguerite.su
- add libpinyin-tools to libpinyin-devel requirement
- fix factory builds for fcitx-libpinyin
* Wed Jul 16 2014 i@marguerite.su
- use update-alternatives to resolve conflicts with libzhuyin
* Fri Feb 28 2014 hillwood@linuxfans.org
- update to 1.0.0
  * bug fixes
  * added some pinyins, such as "陆 liu4", "单 shan4".
- update patch file.
* Wed Jun 26 2013 i@marguerite.su
- update version 0.9.93
  * see commit log for collective updates.
  * https://github.com/libpinyin/libpinyin/commits/master
- add patch: libpinyin-0.9.0-avoid_download_at_buildtime.patch
* Wed Dec 19 2012 hillwood@linuxfans.org
- update 0.8.0.
  bug fixes
* Thu Oct 11 2012 i@marguerite.su
- update 0.7.91
  * a code refator release
* Sun Sep 16 2012 i@marguerite.su
- use upstream standard source.
* Fri Sep 14 2012 i@marguerite.su
- fix fedora builds.
* Mon Sep 10 2012 hillwood@linuxfans.org
- update to 0.7.1
  more changelog please visit http://goo.gl/9bsJj ,only Chinese.
* Mon Aug  6 2012 aj@suse.de
- Remove obsoletes/provides, they are not correct.
* Tue Jul 31 2012 i@marguerite.su
- fix Obsoltes/Provides as AJ suggested.
* Sun Jul 29 2012 hillwood@linuxfans.org
- update to 0.7.0
  * fixes cmake
* Mon Jul 16 2012 hillwood@linuxfans.org
- update to 0.6.92
  * update test_pinyin
  * update utils
* Fri Jun 22 2012 hillwood@linuxfans.org
- update to 0.6.91
- add cmake scripts
- fixes jv,ju in ABC and more
* Sat Jun  2 2012 i@marguerite.su
- fix sles builds.
* Sun Jan 29 2012 i@marguerite.su
- fix Factory libtool build error.
* Sat Jan 28 2012 i@marguerite.su
- Initial package from libpinyin git, version 0.5
